/****************************************************************************
** Meta object code from reading C++ file 'graphlayoutwidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../rocs-26.04.3/libgraphtheory/editorplugins/graphlayout/graphlayoutwidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'graphlayoutwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11GraphTheory17GraphLayoutWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto GraphTheory::GraphLayoutWidget::qt_create_metaobjectdata<qt_meta_tag_ZN11GraphTheory17GraphLayoutWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "GraphTheory::GraphLayoutWidget",
        "layoutGraph",
        "",
        "setSeed",
        "seed",
        "setAreaFactor",
        "areaFactor",
        "setRepellingForce",
        "repellingForce",
        "setAttractionForce",
        "attractionForce",
        "setCurrentTabIndex",
        "index",
        "setRoot",
        "setNodeSeparation",
        "nodeSeparation",
        "freeTreeTypeToggle",
        "checked",
        "rootedTreeTypeToggle"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'layoutGraph'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setSeed'
        QtMocHelpers::SlotData<void(int)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'setAreaFactor'
        QtMocHelpers::SlotData<void(int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'setRepellingForce'
        QtMocHelpers::SlotData<void(int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Slot 'setAttractionForce'
        QtMocHelpers::SlotData<void(int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Slot 'setCurrentTabIndex'
        QtMocHelpers::SlotData<void(const int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Slot 'setRoot'
        QtMocHelpers::SlotData<void(const int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Slot 'setNodeSeparation'
        QtMocHelpers::SlotData<void(const int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'freeTreeTypeToggle'
        QtMocHelpers::SlotData<void(const bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Slot 'rootedTreeTypeToggle'
        QtMocHelpers::SlotData<void(const bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GraphLayoutWidget, qt_meta_tag_ZN11GraphTheory17GraphLayoutWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject GraphTheory::GraphLayoutWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11GraphTheory17GraphLayoutWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11GraphTheory17GraphLayoutWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11GraphTheory17GraphLayoutWidgetE_t>.metaTypes,
    nullptr
} };

void GraphTheory::GraphLayoutWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GraphLayoutWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->layoutGraph(); break;
        case 1: _t->setSeed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->setAreaFactor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->setRepellingForce((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->setAttractionForce((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->setCurrentTabIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->setRoot((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->setNodeSeparation((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->freeTreeTypeToggle((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->rootedTreeTypeToggle((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *GraphTheory::GraphLayoutWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GraphTheory::GraphLayoutWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11GraphTheory17GraphLayoutWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int GraphTheory::GraphLayoutWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}
QT_WARNING_POP
