/****************************************************************************
** Meta object code from reading C++ file 'graph.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../rocs-26.04.3/libgraphtheory/org/kde/rocs/graph.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'graph.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11GraphTheory5GraphE_t {};
} // unnamed namespace

template <> constexpr inline auto GraphTheory::Graph::qt_create_metaobjectdata<qt_meta_tag_ZN11GraphTheory5GraphE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "GraphTheory::Graph",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Backend adapter that is owned by view",
        "createNode",
        "",
        "x",
        "y",
        "typeId",
        "createEdge",
        "GraphTheory::NodeProxy*",
        "from",
        "to",
        "typeIndex",
        "deleteNode",
        "nodeProxy",
        "deleteEdge",
        "GraphTheory::EdgeProxy*",
        "edge"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'createNode'
        QtMocHelpers::SlotData<void(qreal, qreal, int)>(7, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 9 }, { QMetaType::QReal, 10 }, { QMetaType::Int, 11 },
        }}),
        // Slot 'createEdge'
        QtMocHelpers::SlotData<void(GraphTheory::NodeProxy *, GraphTheory::NodeProxy *, int)>(12, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { 0x80000000 | 13, 15 }, { QMetaType::Int, 16 },
        }}),
        // Slot 'deleteNode'
        QtMocHelpers::SlotData<void(GraphTheory::NodeProxy *)>(17, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 18 },
        }}),
        // Slot 'deleteEdge'
        QtMocHelpers::SlotData<void(GraphTheory::EdgeProxy *)>(19, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<Graph, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject GraphTheory::Graph::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11GraphTheory5GraphE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11GraphTheory5GraphE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11GraphTheory5GraphE_t>.metaTypes,
    nullptr
} };

void GraphTheory::Graph::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Graph *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->createNode((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 1: _t->createEdge((*reinterpret_cast<std::add_pointer_t<GraphTheory::NodeProxy*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<GraphTheory::NodeProxy*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 2: _t->deleteNode((*reinterpret_cast<std::add_pointer_t<GraphTheory::NodeProxy*>>(_a[1]))); break;
        case 3: _t->deleteEdge((*reinterpret_cast<std::add_pointer_t<GraphTheory::EdgeProxy*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< GraphTheory::NodeProxy* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< GraphTheory::NodeProxy* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< GraphTheory::EdgeProxy* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *GraphTheory::Graph::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GraphTheory::Graph::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11GraphTheory5GraphE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int GraphTheory::Graph::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}
QT_WARNING_POP
